import { Hono } from 'hono';
import { PostPage } from '@blog/templates/Pages/PostPage';
import { FourOhFour } from '@blog/templates/Pages/FourOhFour';
import { SiteMeta } from '@blog/models/SiteMeta';
import { PostService } from '@blog/services/post-file';

type Posts = {
  postService: PostService 
}

const app = new Hono<{ Variables: Posts }>();

app.get('/:slug', async (c) => {
  const postSlug: string = c.req.param("slug");
  const postService: PostService = c.get('postService');

  try {
    const post = postService.getPost(postSlug);
    const meta: SiteMeta = {
      description: post.meta.description,
      tags: post.meta.tags,
      author: "Dave Smith-Hayes"
    };

    return c.render(<PostPage post={post} />, { meta });
  } catch (e) {
    const description: string = "Page does not exist.";
    console.error(description);
    console.error(e);

    c.status(404);
    const meta: SiteMeta = { description };
    return c.render(<FourOhFour />, { meta });
  }
});

export default app;

